==> master_f_2.4.1.zip: arome/app/src/main/java/com/hh/arome/common/Constants.java <==
package com.hh.arome.common;

import android.os.Build;

import com.hh.arome.BuildConfig;

import java.util.LinkedHashMap;

public class Constants {


    /**
     * 是否调试状态
     */
    public static final Boolean IS_DEBUG = BuildConfig.DEBUG;

    public static class Url {

        public static final String BASE_URL = BuildConfig.BASE_URL;

        // api
        public static final String BASE_API_URL = BuildConfig.BASE_API_URL;

        // 具体接口
        public static final String API_CONFIG_QUERY = "api/v1/iot/device/config/sn/config";
        public static final String API_CONFIG_UPDATE = "api/v1/iot/device/config/sn/updateConfig";
        public static final String API_LOGCAT_ADD = "api/v1/app/log/add";

        public static final String USER_INFO_THREE_ELEMENTS = "https://ldb-permit.hz-hanghui.com:8088/hanghui/outapi/alipayApi/faceAuth/getAlipayUserInfo";

    }


    public static class Value {

        public static final String TOKEN = "edcf7741161b70c0813a05a5e4391fdb";


        public static final String CAMERA_BRAND = "Mario";

        // 设置进入
        public static final String PWD = "HH117521";


        // 业务app心跳
        public static final int TIME_HEARTBEAT = 15 * 1000;

    }


    public static class LogcatValue {

        // 日志各节点
        public static final String LOG_NODE_NET = "网络请求---";
        public static final String LOG_NODE_NET_CONFIG_QUERY = LOG_NODE_NET + "在线配置--获取--";
        public static final String LOG_NODE_NET_CONFIG_UPDATE = LOG_NODE_NET + "在线配置--更新--";
        public static final String LOG_NODE_NET_HEARTBEAT = LOG_NODE_NET + "设备心跳--";
        public static final String LOG_NODE_QR = "二维码---";
        public static final String LOG_NODE_FACE = "BPaaSApi--刷脸---";
        public static final String LOG_NODE_IDCARD = "身份证---";
        public static final String LOG_NODE_DEVICE = "设备信息---";
        public static final String LOG_NODE_APPLET = "小程序---";

        // 对应web的日志类型
        public static final String NET_LOGCAT = "Logcat";
        public static final String NET_ERROR = "Error";
        public static final String NET_CRASH = "Crash";


        public static final String NODE = "日志节点---";
        public static final String LINE = "日志位置---";
        public static final String WARP = " ---\n";
    }


    public static class Ampe {

        // 通道名字
        public static final String AMPE_NAME = "HHCommunication";

        // 二维码
        public static final String ACTION_QR = "getQRCode";
        // 身份证
        public static final String ACTION_IDCard = "getIDCardInfo";
        // 刷脸——初始化startBPass
        public static final String ACTION_INIT_FACE = "initFace";
        // 刷脸
        public static final String ACTION_FACE = "getFaceInfo";
        // 刷脸——江西
        public static final String ACTION_SCAN_FACE = "scanFace";
        // 设备信息
        public static final String ACTION_DEVICE = "getDeviceInfo";

        public static final String AMPE_EVENT = "";

        // 支付宝小程序硬件引擎——包名
        public static final String AMPE_ZFB_ENGINE_PKG = "com.alipay.arome.app";

        // 支付宝小程序硬件引擎——版本号
        public static final String AMPE_ZFB_ENGINE_VERSION_NAME = "10.3.34.679";

    }


    public static class SERVER_ACTION {

        // 设备状态上报
        public static final String REPORT_STATUS = "REPORT_STATUS";

        // 日志拉取
        public static final String FETCH_LOG = "FETCH_LOG";

        // ⽇志下载
        public static final String DOWNLOAD_LOG = "DOWNLOAD_LOG";

        // 应⽤关闭
        public static final String CLOSE_APP = "CLOSE_APP";

        // 设备重启
        public static final String REBOOT = "REBOOT";

        // apk安装升级
        public static final String INSTALL_UPGRADE = "INSTALL_UPGRADE";

        // apk升级进度
        public static final String UPGRADE_PROCESSING = "UPGRADE_PROCESSING";

        // apk停⽌下载
        public static final String STOP_DOWNLOAD = "STOP_DOWNLOAD";

    }

    public static class DeviceModel {

        public static final String K8 = "K8";

        public static final String F10 = "F10";

        public static final String ZP = "HYIP1000-EI";

    }

}

==> master_f_2.6.1.zip: arome/app/src/main/java/com/hh/arome/common/Constants.java <==
package com.hh.arome.common;

import android.os.Build;

import com.hh.arome.BuildConfig;

import java.util.LinkedHashMap;

public class Constants {


    /**
     * 是否正式版本
     * true 非release版本
     * false release版本
     */
    public static final Boolean IS_DEBUG = !BuildConfig.BUILD_TYPE.equals("release");

    /**
     * 是否开启心跳、日志请求
     * true 开启
     * false 关闭
     * 防止调试时过多的请求日志
     * 注意：上线时改为true
     */
    public static final Boolean IS_OPEN_LOG_URL = true;

    public static class Url {

        public static final String BASE_URL = BuildConfig.BASE_URL;

        // api
        public static final String BASE_API_URL = BuildConfig.BASE_API_URL;

        // 具体接口
        public static final String API_CONFIG_QUERY = "api/v1/iot/device/config/sn/config";
        public static final String API_CONFIG_UPDATE = "api/v1/iot/device/config/sn/updateConfig";
        public static final String API_LOGCAT_ADD = "api/v1/app/log/add";

        // 默认三要素url，在线配置
        public static final String USER_INFO_THREE_ELEMENTS = "https://ldb-permit.hz-hanghui.com:8088/hanghui/outapi/alipayApi/faceAuth/getAlipayUserInfo";
        // 默认日志url，在线配置
//        public static final String LOG_URL_DEFAULT = "https://tx.hz-hanghui.com:8088/hanghui-server-platform/api/v1/app/log/add";
        public static final String LOG_URL_DEFAULT = "https://hhomc.hz-hanghui.com:8096/middle-management/api/v1/app/log/push";



    }


    public static class Value {

        public static final String TOKEN = "edcf7741161b70c0813a05a5e4391fdb";


        public static final String CAMERA_BRAND = "Mario";

        // 设置进入
        public static final String PWD = "HH117521";


        // 业务app心跳
        public static final int TIME_HEARTBEAT = 15 * 1000;

    }


    public static class LogcatValue {

        // 日志各节点
        public static final String LOG_NODE_NET = "网络请求---";
        public static final String LOG_NODE_NET_CONFIG_QUERY = LOG_NODE_NET + "在线配置--获取--";
        public static final String LOG_NODE_NET_CONFIG_UPDATE = LOG_NODE_NET + "在线配置--更新--";
        public static final String LOG_NODE_NET_HEARTBEAT = LOG_NODE_NET + "设备心跳--";
        public static final String LOG_NODE_QR = "二维码---";
        public static final String LOG_NODE_FACE = "BPaaSApi--刷脸---";
        public static final String LOG_NODE_IDCARD = "身份证---";
        public static final String LOG_NODE_DEVICE = "设备信息---";
        public static final String LOG_NODE_APPLET = "小程序---";
        public static final String LOG_NODE_SPEECH = "设备信息---";
        public static final String LOG_NODE_AIDL = "aidl---";

        // 对应web的日志类型
        public static final String NET_LOGCAT = "Logcat";
        public static final String NET_ERROR = "Error";
        public static final String NET_CRASH = "Crash";


        public static final String NODE = "日志节点---";
        public static final String LINE = "日志位置---";
        public static final String WARP = " ---\n";
    }


    public static class Ampe {

        // 通道名字
        public static final String AMPE_NAME = "HHCommunication";

        // 二维码
        public static final String ACTION_QR = "getQRCode";
        // 二维码监听，app有消息，就推给小程序
        public static final String EVENT_QR_LISTENER = "initQRListener";
        // 身份证
        public static final String ACTION_IDCard = "getIDCardInfo";
        // 身份证监听，app有消息，就推给小程序
        public static final String EVENT_IDCard_LISTENER = "initIDCardListener";
        // 刷脸——初始化startBPass
        public static final String ACTION_INIT_FACE = "initFace";
        // 刷脸1：N
        public static final String ACTION_FACE = "getFaceInfo";
        // 刷脸1：1人证比对
        public static final String ACTION_FACE_PERSONCARD = "getFaceInfoPersonCard";
        // 刷脸——江西（仅他一家的处理）
        public static final String ACTION_SCAN_FACE = "scanFace";
        // 设备信息
        public static final String ACTION_DEVICE = "getDeviceInfo";
        // 语音播报
        public static final String ACTION_SPEECH = "speech";
        // 手输证件号
        public static final String ACTION_ENTERIDNUMBER  = "enterIDNumber";
        //小票打印
        public static final String ACTION_PRINT = "receiptPrinting";
        public static final String AMPE_EVENT = "";

        // 支付宝小程序硬件引擎——包名
        public static final String AMPE_ZFB_ENGINE_PKG = "com.alipay.arome.app";

        // 支付宝小程序硬件引擎——版本号
        public static final String AMPE_ZFB_ENGINE_VERSION_NAME = "10.3.34.679";

    }


    public static class SERVER_ACTION {

        // 设备状态上报
        public static final String REPORT_STATUS = "REPORT_STATUS";

        // 日志拉取
        public static final String FETCH_LOG = "FETCH_LOG";

        // ⽇志下载
        public static final String DOWNLOAD_LOG = "DOWNLOAD_LOG";

        // 应⽤关闭
        public static final String CLOSE_APP = "CLOSE_APP";

        // 设备重启
        public static final String REBOOT = "REBOOT";

        // apk安装升级
        public static final String INSTALL_UPGRADE = "INSTALL_UPGRADE";

        // apk升级进度
        public static final String UPGRADE_PROCESSING = "UPGRADE_PROCESSING";

        // apk停⽌下载
        public static final String STOP_DOWNLOAD = "STOP_DOWNLOAD";

    }

    public static class DeviceModel {

        public static final String K8 = "K8";

        public static final String F10 = "F10";

        // 紫鹏
        public static final String ZP = "HYIP1000-EI";

        // 访客机d2
        public static final String D2 = "D2";

        public static final String ZP_A10 = "A10";

    }


    public static class Status {



        // 任务状态，最后两位
        // 初始化
        private final int STATUS_TASK_INIT = 0x00000001;// 1
        // 进行中
        private final int STATUS_TASK_DOING = 0x00000002;// 2
        // 等待
        private final int STATUS_TASK_WAIT = 0x00000004;// 4
        // 完成，成功
        private final int STATUS_TASK_COMPLETE = 0x00000008;// 8
        // 错误
        private final int STATUS_TASK_ERROR = 0x00000010;// 16

        // 刷脸任务类型，最后三四位
        // 刷脸初始化
        private final int STATUS_FACE_INIT = 0x00000100;
        // 刷脸1：N
        private final int STATUS_FACE = 0x00000200;
        // 人证1:1
        private final int STATUS_PersonCard = 0x00000400;
        // 初始化和刷脸1：N——天正思维的，江西。先初始化然后直接刷脸
        private final int STATUS_FACE_TZSW = 0x00000800;

        // 其他任务类型，最后五六位
        // 身份证
        private final int STATUS_IDcard = 0x00010000;
        // 二维码
        private final int STATUS_Qr = 0x00020000;
        // 护照机
//        private final int STATUS_Qr = 0x0020000;


    }




}
